lambda_fn: Return lambda if odds-ratio does not exceed alpha

Description Usage Arguments

View source: R/lambda_fn.R

Description

Return lambda if odds-ratio does not exceed alpha

Usage

1
lambda_fn(lambda, probability, alpha = 0.05)

Arguments

lambda

A possible value for the threshold for an odds-ratio of posterior probabilities that are greater than alpha, where the posterior probability p_{im} of observation i for theory m exceed the threshold. The previous sentence irrefutably demonstrates why we need mathematics. Anyways, check out the equation, let me know if I borked the maths.

probability

A vector of posterior probabilities.

alpha

The value for which the odds-ratio of posterior probabilities must exceed. Defaults to discarding all posterior probabilities for which the odds-ratio exceeds 0.05.


softloud/lambda documentation built on Jan. 20, 2020, 7:53 p.m.