lambda_inf: Choose a threshold to classify observations that are...

Description Usage Arguments Details

View source: R/lambda_inf.R

Description

To determine which observations are consistent with each theory or none, a threshold must be chosen above which an observation i is considered consistent with theory m. This function considers all theories and observations and returns the largest threhold.

Usage

1
lambda_inf(probability, alpha = 0.5, precision = 0.001)

Arguments

probability

A vector of posterior probabilities.

alpha

The value for which the odds-ratio of posterior probabilities must exceed. Defaults to discarding all posterior probabilities for which the odds-ratio exceeds 0.05.

precision

what level of precision is required

Details

The function calculates the maximum threshold λ for which (probability of not happening)/(probability of happening) < α for values that exceed threshold λ. (Defaults to α := 0.05)

λ is a possible value for the threshold for an odds-ratio of posterior probabilities that are greater than alpha, where the posterior probability p_{im} of observation i for theory m exceed the threshold. The previous sentence irrefutably demonstrates why we need mathematics. Anyways, check out the equation, let me know if I borked the maths.


softloud/lambda documentation built on Jan. 20, 2020, 7:53 p.m.