Description Usage Arguments Details
To determine which observations are consistent with each theory or none, a threshold must be chosen above which an observation i is considered consistent with theory m. This function considers all theories and observations and returns the largest threhold.
1 | lambda_inf(probability, alpha = 0.5, precision = 0.001)
|
probability |
A vector of posterior probabilities. |
alpha |
The value for which the odds-ratio of posterior probabilities must exceed. Defaults to discarding all posterior probabilities for which the odds-ratio exceeds 0.05. |
precision |
what level of precision is required |
The function calculates the maximum threshold λ for which (probability of not happening)/(probability of happening) < α for values that exceed threshold λ. (Defaults to α := 0.05)
λ is a possible value for the threshold for an odds-ratio of posterior probabilities that are greater than alpha, where the posterior probability p_{im} of observation i for theory m exceed the threshold. The previous sentence irrefutably demonstrates why we need mathematics. Anyways, check out the equation, let me know if I borked the maths.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.